@@ -8,6 +8,8 @@ class Finding:
         controlId: string
         Reason: list of strings
         Identifier: string
+        IdentifierType: string
+        Region: (Optional) string
         """
         self.id = kwargs.get('id')
         self.target = kwargs.get('target', '')
@@ -15,6 +17,8 @@ class Finding:
         self.Reason = kwargs.get('reason', [])
         self.Identifier = kwargs.get('identifier', '')
         self.IdentifierType = kwargs.get('identifier_type', '')
+        if kwargs.get('region'):
+            self.Region = kwargs['region']
 
     def json(self) -> dict:
         json_obj = self.__dict__
